==> EMC2_3.2.0.tar.gz: EMC2/tests/testthat/_snaps/group.md <==
# groups

    Code
      print(group_des)
    Output
      v_S1 ~ age + group 
      a ~ age 

---

    Code
      summary(group_des)
    Output
      
       Sampled Parameters: 
      [1] "v_S1"        "v_S1_age"    "v_S1_group1" "a"           "a_age"      
      
       Design Matrices: 
      $v_S1
                 age group v_S1  v_S1_age v_S1_group1
      as1t -8.940005     A    1 -8.940005  -0.7071068
      bd6t -7.940005     B    1 -7.940005   0.7071068
      bl1t -6.940005     A    1 -6.940005  -0.7071068
      
      $a
                 age a     a_age
      as1t -8.940005 1 -8.940005
      bd6t -7.940005 1 -7.940005
      bl1t -6.940005 1 -6.940005
      

---

    Code
      credint(pri, group_design = group_des)
    Output
      $mu
                    2.5%    50%  97.5%
      v_Sleft     -2.935 -0.048  2.635
      v_Sright    -2.703 -0.103  2.763
      a_Espeed     0.134  1.028  7.300
      a_Eneutral   0.068  1.041 14.773
      a_Eaccuracy  0.065  1.080 19.877
      t0           0.134  1.012  6.364
      

---

    Code
      credint(pri, group_design = group_des, selection = "beta")
    Output
      $beta
                    2.5%    50% 97.5%
      v           -1.990 -0.028 1.954
      v_S1        -1.971  0.021 2.086
      v_S1_age    -1.933  0.004 1.850
      v_S1_group1 -1.890  0.025 1.980
      a           -1.980  0.011 1.933
      a_age       -2.021  0.005 1.940
      a_Eneutral  -1.915 -0.068 1.948
      a_Eaccuracy -2.041  0.081 1.984
      t0          -2.116 -0.031 1.990
      

---

    Code
      init_chains(emc, particles = 10, cores_per_chain = 1)[[1]]$samples
    Output
      $theta_mu
                         [,1]
      v           -0.03888017
      v_S1        -0.78728938
      v_S1_age    -0.39984387
      v_S1_group1 -0.26955805
      a            1.19149532
      a_age       -1.23103024
      a_Eneutral   0.35470643
      a_Eaccuracy  1.05336362
      t0          -0.79660492
      
      $theta_var
      , , 1
      
                             v         v_S1            a   a_Eneutral  a_Eaccuracy
      v            0.113690464 -0.008343548  0.028910064  0.015962820 -0.020590978
      v_S1        -0.008343548  0.068236226  0.006772876  0.015285582  0.012828397
      a            0.028910064  0.006772876  0.059430759  0.018221540  0.005440499
      a_Eneutral   0.015962820  0.015285582  0.018221540  0.069656161 -0.004365777
      a_Eaccuracy -0.020590978  0.012828397  0.005440499 -0.004365777  0.053726364
      t0          -0.033944561  0.022072794 -0.033120945  0.014419211 -0.005044170
                           t0
      v           -0.03394456
      v_S1         0.02207279
      a           -0.03312095
      a_Eneutral   0.01441921
      a_Eaccuracy -0.00504417
      t0           0.13518050
      
      
      $a_half
                        [,1]
      v            4.1079468
      v_S1        18.3272435
      a            0.8471773
      a_Eneutral   2.0441703
      a_Eaccuracy  0.7029995
      t0           0.1776038
      
      $alpha
      , , 1
      
                        as1t        bd6t        bl1t       hsft       hsgt       kd6t
      v           -0.2793138  0.06326437 -0.05179043  0.1753138  0.5369034  0.3183366
      v_S1         2.8961923  2.48644309  2.10565572  1.2343095  1.1818893  0.7622669
      a           11.9721108 11.33587212  9.94820331  8.9841802  7.7385271  6.0509591
      a_Eneutral   0.2693660  0.43569557  0.44753382  0.2416477  0.9928261  0.2184930
      a_Eaccuracy  0.8727936  1.10349647  1.00413811  1.0713548  0.7956523  0.7775872
      t0          -0.5974286 -0.17877815 -0.93209287 -1.5775615 -0.7390896 -0.9409823
                        kd9t        kh6t       kmat        ku4t        na1t
      v           -0.4319053 -0.38291046 -0.4526971 -0.18039645  0.05336898
      v_S1         0.2043612  0.04215716 -0.6442111 -0.90050105 -1.13106163
      a            4.2961019  3.15119690  1.6181717  1.16115211 -0.42934921
      a_Eneutral   0.3045865  0.18030573  0.4621190  0.02720303  0.22476835
      a_Eaccuracy  0.8623248  1.18310037  1.2287033  0.98779517  0.99894812
      t0          -0.4646298 -0.21890809 -0.4604196 -1.07868499 -1.18991516
                         rmbt       rt2t       rt3t        rt5t        scat
      v           -0.06841431 -0.1322083 -0.3920500  0.09999397 -0.69244227
      v_S1        -1.91832822 -1.6315909 -2.3255022 -2.41602061 -3.48707790
      a           -1.18850418 -2.4011468 -4.1214458 -4.53837058 -6.70886635
      a_Eneutral   0.34439630  0.6357496  0.3130787  0.21796538  0.04110644
      a_Eaccuracy  1.28628732  1.3566332  0.9202600  1.21462116  1.00516636
      t0          -1.29404895 -1.1054786 -0.5831673 -0.48145817 -0.16314655
                         ta5t       vf1t       zk1t
      v           -0.27714885 -0.4038693  0.2981249
      v_S1        -3.16599337 -4.1200727 -3.6081913
      a           -7.51474735 -8.5077215 -9.8069640
      a_Eneutral   0.04611075  0.3301294  0.6441204
      a_Eaccuracy  1.56515278  1.0053854  1.1225618
      t0          -0.22242109 -1.1196025 -1.0699364
      
      
      $stage
      [1] "init"
      
      $subj_ll
                 [,1]
      as1t -18650.939
      bd6t -19548.947
      bl1t -19410.792
      hsft -19525.922
      hsgt -19548.947
      kd6t -19548.947
      kd9t -19548.947
      kh6t -19272.637
      kmat -19281.459
      ku4t -16294.914
      na1t  -2212.878
      rmbt  -3251.588
      rt2t  -8633.725
      rt3t -18778.829
      rt5t -15797.303
      scat -19548.947
      ta5t -19456.844
      vf1t -19295.663
      zk1t -18558.836
      
      $last_theta_var_inv
                 [,1]       [,2]      [,3]      [,4]      [,5]      [,6]
      [1,] 11.7538788  0.6962788 -4.517923 -1.796096  4.847517  2.103288
      [2,]  0.6962788 17.4903358 -2.891158 -2.830369 -4.151008 -3.242408
      [3,] -4.5179228 -2.8911581 24.953865 -6.319364 -3.518817  5.994380
      [4,] -1.7960958 -2.8303686 -6.319364 17.851181  1.761025 -3.375590
      [5,]  4.8475169 -4.1510082 -3.518817  1.761025 22.118076  1.670355
      [6,]  2.1032882 -3.2424077  5.994380 -3.375590  1.670355 10.346186
      
      $idx
      [1] 1

==> EMC2_3.2.1.tar.gz: EMC2/tests/testthat/_snaps/group.md <==
# groups

    Code
      print(group_des)
    Output
      v_S1 ~ age + group 
      a ~ age 

---

    Code
      summary(group_des)
    Output
      
       Sampled Parameters: 
      [1] "v_S1"        "v_S1_age"    "v_S1_group1" "a"           "a_age"      
      
       Design Matrices: 
      $v_S1
                 age group v_S1  v_S1_age v_S1_group1
      as1t -8.940005     A    1 -8.940005  -0.7071068
      bd6t -7.940005     B    1 -7.940005   0.7071068
      bl1t -6.940005     A    1 -6.940005  -0.7071068
      
      $a
                 age a     a_age
      as1t -8.940005 1 -8.940005
      bd6t -7.940005 1 -7.940005
      bl1t -6.940005 1 -6.940005
      

---

    Code
      credint(pri, group_design = group_des, map = FALSE)
    Output
      $mu
                    2.5%    50% 97.5%
      v           -1.915 -0.075 2.013
      v_S1        -1.919 -0.023 1.920
      a           -2.013  0.028 1.988
      a_Eneutral  -1.734 -0.014 1.840
      a_Eaccuracy -1.878  0.076 1.935
      t0          -2.013  0.012 1.851
      

---

    Code
      credint(pri, group_design = group_des, selection = "beta")
    Output
      $beta
                    2.5%    50% 97.5%
      v           -1.990 -0.028 1.954
      v_S1        -1.971  0.021 2.086
      v_S1_age    -1.933  0.004 1.850
      v_S1_group1 -1.890  0.025 1.980
      a           -1.980  0.011 1.933
      a_age       -2.021  0.005 1.940
      a_Eneutral  -1.915 -0.068 1.948
      a_Eaccuracy -2.041  0.081 1.984
      t0          -2.116 -0.031 1.990
      

---

    Code
      init_chains(emc, particles = 10, cores_per_chain = 1)[[1]]$samples
    Output
      $theta_mu
                         [,1]
      v           -0.03888017
      v_S1        -0.78728938
      v_S1_age    -0.39984387
      v_S1_group1 -0.26955805
      a            1.19149532
      a_age       -1.23103024
      a_Eneutral   0.35470643
      a_Eaccuracy  1.05336362
      t0          -0.79660492
      
      $theta_var
      , , 1
      
                             v         v_S1            a   a_Eneutral  a_Eaccuracy
      v            0.113690464 -0.008343548  0.028910064  0.015962820 -0.020590978
      v_S1        -0.008343548  0.068236226  0.006772876  0.015285582  0.012828397
      a            0.028910064  0.006772876  0.059430759  0.018221540  0.005440499
      a_Eneutral   0.015962820  0.015285582  0.018221540  0.069656161 -0.004365777
      a_Eaccuracy -0.020590978  0.012828397  0.005440499 -0.004365777  0.053726364
      t0          -0.033944561  0.022072794 -0.033120945  0.014419211 -0.005044170
                           t0
      v           -0.03394456
      v_S1         0.02207279
      a           -0.03312095
      a_Eneutral   0.01441921
      a_Eaccuracy -0.00504417
      t0           0.13518050
      
      
      $a_half
                        [,1]
      v            4.1079468
      v_S1        18.3272435
      a            0.8471773
      a_Eneutral   2.0441703
      a_Eaccuracy  0.7029995
      t0           0.1776038
      
      $alpha
      , , 1
      
                        as1t        bd6t        bl1t       hsft       hsgt       kd6t
      v           -0.2793138  0.06326437 -0.05179043  0.1753138  0.5369034  0.3183366
      v_S1         2.8961923  2.48644309  2.10565572  1.2343095  1.1818893  0.7622669
      a           11.9721108 11.33587212  9.94820331  8.9841802  7.7385271  6.0509591
      a_Eneutral   0.2693660  0.43569557  0.44753382  0.2416477  0.9928261  0.2184930
      a_Eaccuracy  0.8727936  1.10349647  1.00413811  1.0713548  0.7956523  0.7775872
      t0          -0.5974286 -0.17877815 -0.93209287 -1.5775615 -0.7390896 -0.9409823
                        kd9t        kh6t       kmat        ku4t        na1t
      v           -0.4319053 -0.38291046 -0.4526971 -0.18039645  0.05336898
      v_S1         0.2043612  0.04215716 -0.6442111 -0.90050105 -1.13106163
      a            4.2961019  3.15119690  1.6181717  1.16115211 -0.42934921
      a_Eneutral   0.3045865  0.18030573  0.4621190  0.02720303  0.22476835
      a_Eaccuracy  0.8623248  1.18310037  1.2287033  0.98779517  0.99894812
      t0          -0.4646298 -0.21890809 -0.4604196 -1.07868499 -1.18991516
                         rmbt       rt2t       rt3t        rt5t        scat
      v           -0.06841431 -0.1322083 -0.3920500  0.09999397 -0.69244227
      v_S1        -1.91832822 -1.6315909 -2.3255022 -2.41602061 -3.48707790
      a           -1.18850418 -2.4011468 -4.1214458 -4.53837058 -6.70886635
      a_Eneutral   0.34439630  0.6357496  0.3130787  0.21796538  0.04110644
      a_Eaccuracy  1.28628732  1.3566332  0.9202600  1.21462116  1.00516636
      t0          -1.29404895 -1.1054786 -0.5831673 -0.48145817 -0.16314655
                         ta5t       vf1t       zk1t
      v           -0.27714885 -0.4038693  0.2981249
      v_S1        -3.16599337 -4.1200727 -3.6081913
      a           -7.51474735 -8.5077215 -9.8069640
      a_Eneutral   0.04611075  0.3301294  0.6441204
      a_Eaccuracy  1.56515278  1.0053854  1.1225618
      t0          -0.22242109 -1.1196025 -1.0699364
      
      
      $stage
      [1] "init"
      
      $subj_ll
                 [,1]
      as1t -18650.939
      bd6t -19548.947
      bl1t -19410.792
      hsft -19525.922
      hsgt -19548.947
      kd6t -19548.947
      kd9t -19548.947
      kh6t -19272.637
      kmat -19281.459
      ku4t -16294.914
      na1t  -2212.878
      rmbt  -3251.588
      rt2t  -8633.725
      rt3t -18778.829
      rt5t -15797.303
      scat -19548.947
      ta5t -19456.844
      vf1t -19295.663
      zk1t -18558.836
      
      $last_theta_var_inv
                 [,1]       [,2]      [,3]      [,4]      [,5]      [,6]
      [1,] 11.7538788  0.6962788 -4.517923 -1.796096  4.847517  2.103288
      [2,]  0.6962788 17.4903358 -2.891158 -2.830369 -4.151008 -3.242408
      [3,] -4.5179228 -2.8911581 24.953865 -6.319364 -3.518817  5.994380
      [4,] -1.7960958 -2.8303686 -6.319364 17.851181  1.761025 -3.375590
      [5,]  4.8475169 -4.1510082 -3.518817  1.761025 22.118076  1.670355
      [6,]  2.1032882 -3.2424077  5.994380 -3.375590  1.670355 10.346186
      
      $idx
      [1] 1
